@@ -52,7 +52,7 @@ class Word:
         self.webdict = kwargs.get("webdict")["url"]
 
     def __repr__(self) -> str:
-        return self.translation[0] + f"({self.webdict['url']})"
+        return self.translation + f"({self.webdict})"
 
 
 def encrypt(signStr):
@@ -131,9 +131,4 @@ if __name__ == '__main__':
     txt = connect("xvab")
     print(txt)
     word = Word(**json.loads(txt))
-    print(word.translation)
-    print(word.is_word)
-    print(f"speakUrl:{word.speakUrl}")
-    print(f"webdict:{word.webdict}")
-    print(f"basic: {word.basic}")
-    print(f"web: {word.web}")
\ No newline at end of file
+    print(word)
